@@ -110,13 +110,14 @@ void checkDimension(int polyDim, int codim, int index){
       if (codim > 1){
 	printf("Please increase POLY_Dmax to at least %d = %d + %d - 1\n",
 	       (polyDim + codim - 1), polyDim, codim);
-	puts("(nef.x requires POLY_Dmax >= dim N + codim - 1)");}
+	printf("(POLY_Dmax >= dim N + codim - 1 is required)\n");}
       else printf("Please increase POLY_Dmax to at least %d\n", polyDim);
       exit(0);  }}
   else if (POLY_Dmax  < polyDim +1){
     printf("Please increase POLY_Dmax to at least %d = %d + 1\n",
 	   (polyDim + 1), polyDim);
-    puts("(nef.x -G requires POLY_Dmax >= dim(cone) = dim(support) + 1)");
+    printf("(option -G requires POLY_Dmax >= dim(cone) = dim(support) + 1)\n"
+	   );
     exit(0);}
 }
  
@@ -205,7 +206,7 @@ MAP: for(i=0;i<_CW->nw;i++)			/* check consistency of CWS */
      {	Long sum = _CW->d[i] * index, *w = _CW->W[i];
 	for(j=0;j<_CW->N;j++) { assert(w[j]>=0); sum-=w[j]; }
 	if((sum)&&(index==1)){ 
-	  printf("Use poly.x -l for (single) WeightSystems with ");
+	  printf("Use option -l for (single) WeightSystems with ");
 	  printf("d!=\\sum(w)\n(only Read_Weight makes the correct ");
 	  puts("PolyPointList in that case)"); exit(0);}
      }
@@ -325,10 +326,12 @@ int  Read_CWS(CWS *_CW, PolyPointList *_P)
 MAP: for(i=0;i<_CW->nw;i++)			/* check consistency of CWS */
      {	Long sum=_CW->d[i], *w=_CW->W[i];
 	for(j=0;j<_CW->N;j++) { assert(w[j]>=0); sum-=w[j]; }
-	if(sum){ printf("Use poly.x -w for (single) WeightSystems with ");
-		printf("d!=\\sum(w)\n(only Read_Weight makes the correct ");
-		puts("PolyPointList in that case)"); exit(0);}
-     }
+	if(sum){ /*printf("Use poly.x -w for (single) WeightSystems with ");
+		   printf("d!=\\sum(w)\n(only Read_Weight makes the correct ");
+		   puts("PolyPointList in that case)"); exit(0);*/
+	  printf("cannot handle (single) WeightSystems with ");
+	  printf("d!=\\sum(w)\n");
+	  exit(0);}}
      _CW->nz=0;
      if(!Read_CWS_Zinfo(inFILE,_CW))			   /* read Z to EOL */
      {	if(!InputOK) puts("-h gives you help\n"); return 0;}
