@@ -1419,7 +1419,7 @@ void AnalyseGorensteinCone(CWS *_CW,  PolyPointList *_P, VertexNumList *_V,
   if (POLY_Dmax  < _P->n + 1){/* only relevant if index == 1 */
     printf("Please increase POLY_Dmax to at least %d = %d + 1\n",
 	   (_P->n + 1), _P->n);
-    puts("(nef.x -G requires POLY_Dmax >= dim(cone) = dim(support) + 1)");
+    printf("(POLY_Dmax >= dim(cone) = dim(support) + 1 required)\n");
     assert(*_codim == 1);
     exit(0);}
   /* Print_PPL(_P, "_P before sorting");fflush(0); */
