@@ -19,7 +19,10 @@ For higher dimensional or complicated non-reflexive polytopes it may be
 necessary to set even Long to 64 bits.
 */
 
+#ifndef POLY_Dmax       /* You can set POLY_Dmax at compilation:
+                           use -D POLY_Dmax=<value> in the C flags  */
 #define   		POLY_Dmax	6	/* max dim of polytope	    */
+#endif
 /*
 POLY_Dmax should be set to the dimension of the polytopes that are analysed.
 While the programs still work if POLY_Dmax is set to a higher value, they may
@@ -92,6 +95,11 @@ Max number of codimension 2 faces.
 Uses W_to_GLZ like in Rat.c
 */
 
+#define MAXLD (26)
+
+/*
+Used in the handling of large lists of weight systems (cf. C5stats)
+*/
 
 extern FILE *inFILE, *outFILE;
 /*
@@ -145,7 +153,7 @@ the equations (a,c).
 */
 
 typedef struct {int mp, mv, np, nv, n, pic, cor, h22, h1[POLY_Dmax-1];}
-                                                             BaHo;
+                                                                     BaHo;
 /*
 This structure is related to Batyrev's formulas for Hodge numbers.
 n     ... dimension of the polytope
@@ -158,18 +166,28 @@ repectively.
 */
 
 typedef struct {
-	Long W[FIB_Nmax][VERT_Nmax]; 
-	int nw, PS, ZS, nv, f[VERT_Nmax],r[VERT_Nmax],nf,nz[FIB_Nmax], n0[FIB_Nmax],
-         Z[FIB_Nmax][VERT_Nmax], M[FIB_Nmax];
-	GL_Long G[VERT_Nmax][POLY_Dmax][POLY_Dmax];
-	PolyPointList *P;
-} FibW;
+  Long W[FIB_Nmax][VERT_Nmax]; 
+  int nw, PS, ZS, nv, f[VERT_Nmax],r[VERT_Nmax],nf,nz[FIB_Nmax], n0[FIB_Nmax],
+    Z[FIB_Nmax][VERT_Nmax], M[FIB_Nmax];
+  GL_Long G[VERT_Nmax][POLY_Dmax][POLY_Dmax];
+  PolyPointList *P;
+}                                                                     FibW;
 /*
 This list is an extension of the PolyPointList with the combined weight system.
 W[i][j] is the j'th weight; nw is the number of weight systems.
 */
 
-
+typedef struct{
+  long n_nonIP, n_IP_nonRef, n_ref, // numbers of WS of certain types
+    max_w, nr_max_w, //maximum weight in the reflexive/non-reflexive cases
+    nr_n_w[MAXLD], n_w[MAXLD]; //numbers of weights of given [ld]
+  int nr_max_mp, nr_max_mv, nr_max_nv, max_mp, max_mv, max_np, max_nv,
+    max_h22, max_h1[POLY_Dmax-1], //max values of certain entries of BH
+    min_chi, max_chi, max_nf[POLY_Dmax+1]; //range for chi, max facet numbers
+}                                                                     C5stats;
+/* 
+statistics on large lists of weight systems, cf. classification of 4fold weights
+*/
 
 /*  ==========         I/O functions (from Coord.c)		==========  */
 
@@ -241,6 +259,12 @@ As an example, the complete output for the quintic threefold reads
 5 1 1 1 1 1 M:126 5 N:6 5 H:1,101 [-200].
 */
 
+void Initialize_C5S(C5stats *_C5S, int n);
+void Update_C5S(BaHo *_BH, int *nf, Long *W, C5stats *_C5S);
+void Print_C5S(C5stats *_C5S);
+/*
+Routines for handling the structure C5stats
+*/
 
 /*  ==========              From Polynf.c                        ========== */
 
@@ -578,3 +602,7 @@ void Print_FaceInfo(int n, FaceInfo *FI);
 Displays the information contained in the FaceInfo *FI.
 */
 
+int QuickAnalysis(PolyPointList *_P, BaHo *_BH, FaceInfo *_FI);
+/*
+Fast computation of FaceInfo and Hodge numbers.
+*/
