@@ -24,8 +24,10 @@ void WZerror(char *c)
 }    
 int  auxString2SInt(char *c,int *n)
 {    int j=0,neg=0; *n=0;     if(c[0]=='-')if(('0'<c[1])&&(c[1]<='9')) neg=j=1;
-     while(('0'<=c[j])&&(c[j]<='9')) *n = 10*(*n)+c[j++]-'0';   if(neg)*n *=-1;
-     if(j) while(c[j]==' ') j++; return j;
+     while(('0'<=c[j])&&(c[j]<='9')) *n = 10*(*n)+c[j++]-'0';
+     if(neg)*n *=-1;
+     if(j) while(c[j]==' ') j++;
+     return j;
 }
 int  Read_WZ_PP(Weight *WZ)     /* read "d w_i" [ or "w_i d" if last=max ] */
 {    int i,j,k,a,n,d,shift=1, I[W_Nmax+2], *nz=&WZ->M; 
@@ -50,11 +52,14 @@ int  Read_WZ_PP(Weight *WZ)     /* read "d w_i" [ or "w_i d" if last=max ] */
 	if(feof(inFILE)) {if(FilterFlag) inFILE=NULL; return 0;} 
 	if(c[n]=='\n') break;
      }  if(n==999) {puts("Out of space in Read_WZeight");exit(0);} i=0;
-     while(c[i]==b)i++; if((c[i]=='=')&&(c[i+1]=='d'))i+=2; while(c[i]==b)i++; 
+     while(c[i]==b)i++;
+     if((c[i]=='=')&&(c[i+1]=='d'))i+=2;
+     while(c[i]==b)i++; 
      while(i<n)
      {  int j, k, s; if((c[i]!='/')||(c[i+1]!='Z')) break;
         i+=2; assert(*nz<POLY_Dmax);		 WZ->m[*nz]=0;
-	while((i<n)&&IsDigit(c[i])) WZ->m[*nz]=10*WZ->m[*nz]+c[i++]-'0';j=0;
+	while((i<n)&&IsDigit(c[i])) WZ->m[*nz]=10*WZ->m[*nz]+c[i++]-'0';
+	j=0;
 	if(WZ->m[*nz]<=0) WZerror("Order not positive");
 	    if(c[i+j]!=':') WZerror(":"); else {i+=j+1; while(c[i]==b)i++;}
             for(k=0;k<WZ->N;k++)
@@ -83,9 +88,11 @@ int  Read_WZ_PP(Weight *WZ)     /* read "d w_i" [ or "w_i d" if last=max ] */
 	assert(0==(X%WZ->B[i][i-1])); WZ->rI[i-1]=X/WZ->B[i][i-1];}
      for(i=0;i<*nz;i++)				    /* divide by symmetries: */
      {	Long g=WZ->m[i]; X=0; for(j=0;j<d;j++){Za[j]=0; 
-	for(k=0;k<a;k++)Za[j]+=WZ->z[i][k]*WZ->B[k][j]; g=NNgcd(Za[j],g);}
+	for(k=0;k<a;k++)Za[j]+=WZ->z[i][k]*WZ->B[k][j];
+	g=NNgcd(Za[j],g);}
 if(Tout){printf("WZ->m[%d]=%d g=%ld  ",i,WZ->m[i],g);if(g==WZ->m[i])puts("");}
-	if(g==WZ->m[i]) continue; if(g>1) for(k=0;k<a;k++) Za[j]/=g; 
+	if(g==WZ->m[i]) continue;
+	if(g>1) for(k=0;k<a;k++) Za[j]/=g; 
 	V_to_G_GI(Za,d,G,GI); for(k=0;k<a;k++)
 	{   int l; for(l=0;l<d;l++) Wa[l]=WZ->B[k][l]; for(l=0;l<d;l++) 
 	    {	WZ->B[k][l]=0; for(j=0;j<d;j++) WZ->B[k][l] += Wa[j]*G[l][j];
@@ -93,7 +100,7 @@ if(Tout){printf("WZ->m[%d]=%d g=%ld  ",i,WZ->m[i],g);if(g==WZ->m[i])puts("");}
 	    X+=WZ->z[i][k]*(WZ->A[k]-F[k]); 
 	}   X%=WZ->m[i];/* IP = r*A+B.rI, B'=B.G^T => rI' = GI^T . rI + r dx */
 	if(X<-WZ->m[i]/2)X+=WZ->m[i]; else if(X>WZ->m[i]/2)X-=WZ->m[i];
-if(Tout)printf("X=%ld\n",X);
+	if(Tout) printf("X=%ld\n",X);
 	for(k=0;k<a;k++) WZ->A[k]-=X*WZ->B[k][0];
 	for(j=0;j<d;j++) {Za[j]=WZ->rI[j]; WZ->rI[j]=0;} WZ->rI[0] =X*WZ->r;
 	for(j=0;j<d;j++) for(k=0;k<d;k++) WZ->rI[j]+=Za[k]*GI[k][j];
@@ -101,11 +108,13 @@ if(Tout)printf("X=%ld\n",X);
 	assert((WZ->rI[0]%g)==0); WZ->rI[0]/=g; shift*=g;
      }	X=1; for(j=0;j<*nz;j++) X*=WZ->m[j]; assert(X%shift==0); shift=X/shift;
 
-if(Tout){for(j=0;j<a;j++)printf("%2ld ", WZ->A[j]);printf("=A rI=");
-for(j=0;j<d;j++)printf("%2ld ", WZ->rI[j]);puts("");
-for(k=0;k<a;k++){for(j=0;j<d;j++)printf("%2ld ",WZ->B[k][j]);puts("=B");} 
-for(j=0;j<a;j++){X=0;for(k=0;k<d;k++)X+=WZ->B[j][k]*WZ->rI[k];
-printf("%2ld ",X);}puts("=B.rI");Write_Weight(WZ);} 
+if(Tout){for(j=0;j<a;j++)printf("%2ld ", WZ->A[j]); printf("=A rI=");
+  for(j=0;j<d;j++) printf("%2ld ", WZ->rI[j]);
+  puts("");
+  for(k=0;k<a;k++){for(j=0;j<d;j++)printf("%2ld ",WZ->B[k][j]);puts("=B");} 
+  for(j=0;j<a;j++){X=0;for(k=0;k<d;k++)X+=WZ->B[j][k]*WZ->rI[k];
+    printf("%2ld ",X);}
+  puts("=B.rI");Write_Weight(WZ);} 
 
      {	PairMat VPM; VertexNumList V; PolyPointList *P=WZ->P;
 	EqList *E=(EqList *)malloc(sizeof(EqList));assert(E!=NULL);
@@ -114,7 +123,8 @@ printf("%2ld ",X);}puts("=B.rI");Write_Weight(WZ);}
 	WZ->P->n=d; WZ->P->np=0; Complete_Poly(VPM,E,1,WZ->P);
 /*	    assert(POINT_Nmax>WZ->P->np); / * Print_PPL(WZ->P,""); obsolete */
 /*	    for(i=0;i<d;i++) WZ->P->x[WZ->P->np][i]=WZ->rI[i]; / * obsolete */
-	for(i=0;i<d;i++) if(WZ->rI[i]) break; if(i<d) /* rI!=0 => make P0=0 */
+	for(i=0;i<d;i++) if(WZ->rI[i]) break;
+	if(i<d) /* rI!=0 => make P0=0 */
 	{   for(i=1;i<P->np;i++) for(j=0;j<d;j++) P->x[i][j]-=P->x[0][j];
 	    for(i=0;i<a;i++)for(j=0;j<d;j++) WZ->A[i]+=WZ->B[i][j]*P->x[0][j];
 	    for(i=0;i<d;i++) {WZ->rI[i]-=WZ->r*P->x[0][i]; P->x[0][i]=0;}
@@ -131,18 +141,22 @@ printf("%2ld ",X);}puts("=B.rI");Write_Weight(WZ);}
 	WZ->M=k;	/* printf("shift=%d   rank=%d \n",shift,k); */
      }	X=0; for(j=0;j<a;j++) X+=WZ->w[j]*WZ->A[j];		    /* X=w.A */
      for(i=0;i<WZ->M;i++) {Long A=0,M=WZ->m[i],cx,cm,g;		    /* A=Z.A */
-	for(j=0;j<a;j++) A+=WZ->z[i][j]*WZ->A[j]; if(0==(A%=M)) continue; 
+	for(j=0;j<a;j++) A+=WZ->z[i][j]*WZ->A[j];
+	if(0==(A%=M)) continue; 
 	g=Egcd(X%M,M,&cx,&cm); assert(0==(A%g));     /* Z_i -= cx * A/g * w_ */
 	cx*=A/g; if(cx>0)cx-=M; 
 	for(j=0;j<a;j++) {WZ->z[i][j]-=cx*WZ->w[j]; WZ->z[i][j]%=M;}
      }
      X=0;for(j=0;j<a;j++)X+=WZ->w[j]*WZ->A[j];assert(X==WZ->d);/* TEST w.A=d */
-     for(j=0;j<a;j++){ X=WZ->r*WZ->A[j]; for(k=0;k<d;k++)
-	X+=WZ->B[j][k]*WZ->rI[k];assert(X==1);}	      /* TEST:  r*A+B.rI==IP */
+     for(j=0;j<a;j++){
+       X=WZ->r*WZ->A[j];
+       for(k=0;k<d;k++) X+=WZ->B[j][k]*WZ->rI[k];
+       assert(X==1);}	      /* TEST:  r*A+B.rI==IP */
      for(i=0;i<WZ->M;i++) {X=0; for(j=0;j<a;j++)
 	X+=WZ->z[i][j]*WZ->A[j];assert(0==X%WZ->m[i]);}/* TEST: A*z[]%m[]==0 */
      
-     if(FilterFlag) inFILE=NULL; return 1;
+     if(FilterFlag) inFILE=NULL;
+return 1;
 }
 
 
@@ -188,15 +202,16 @@ int  Read_Weight(Weight *_W)     /* read "d w_i" [ or "w_i d" if last=max ] */
      for(i=0;i<=_W->N;i++) assert(I[i]>0);
      if(I[_W->N]>I[0]) { _W->d=I[_W->N]; shift=0; } else _W->d=I[0];
      for(i=0;i<_W->N;i++) {_W->w[i]=I[i+shift]; assert(_W->w[i]<_W->d);} 
-     if(FilterFlag) inFILE=NULL; return 1;
+     if(FilterFlag) inFILE=NULL;
+     return 1;
 }
 void Write_WH(Weight *_W, BaHo *_BH, VaHo *_VH, int rc, int tc,
 	      PolyPointList *_P, VertexNumList *_V, EqList *_E){
-  int i;
+  int i, j;
 #if	WZinput
   fprintf(outFILE,"%d ",(int)_W->d);
   for(i=0;i<_W->N;i++) fprintf(outFILE,"%d ",(int)_W->w[i]);
-  for(i=0;i<_W->M;i++){int j; fprintf(outFILE,"/Z%d: ",(int)_W->m[i]);
+  for(i=0;i<_W->M;i++){fprintf(outFILE,"/Z%d: ",(int)_W->m[i]);
     for(j=0;j<_W->N;j++)fprintf(outFILE,"%d ",(int)_W->z[i][j]);}
 #else  
   for(i=0;i<_W->N;i++) fprintf(outFILE,"%d ",(int)_W->w[i]); 
@@ -205,28 +220,34 @@ void Write_WH(Weight *_W, BaHo *_BH, VaHo *_VH, int rc, int tc,
   fprintf(outFILE,"M:%d %d ",_P->np,_V->nv);  /* PolyData */
   if(rc) fprintf(outFILE,"N:%d %d ",_BH->np,_E->ne); 
   else fprintf(outFILE,"F:%d ",_E->ne); 		 /* END of PolyData */
-  if(tc&&(_P->n!=1+_VH->D)) {int D=0, d=_W->d;		/* LG non-geometric */
-     fprintf(outFILE,"LG: "); for(i=0;i<_W->N;i++) D+=d-2*_W->w[i]; 
-     if(D%d) {int g=Fgcd(D,d); fprintf(outFILE,"c/3=%d/%d\n",D/g,d/g);}
-     else { int r=_W->N-(D/=d); if((r%2)||(r<=2)) r=0;assert(D==_VH->D);
-        for(i=0;i<=D;i++) {int j; fprintf(outFILE,"%sH%d:",i?" ":"",i);
+  if(tc&&(_P->n!=1+_VH->D)) {
+    int D=0, d=_W->d;		/* LG non-geometric */
+    fprintf(outFILE,"LG: "); for(i=0;i<_W->N;i++) D+=d-2*_W->w[i]; 
+    if(D%d) {int g=Fgcd(D,d); fprintf(outFILE,"c/3=%d/%d\n",D/g,d/g);}
+    else { int r=_W->N-(D/=d); if((r%2)||(r<=2)) r=0;assert(D==_VH->D);
+      for(i=0;i<=D;i++) {fprintf(outFILE,"%sH%d:",i?" ":"",i);
         for(j=0;j<=D-i;j++)fprintf(outFILE,"%s%d",j?",":"",(int)_VH->h[i][j]);}
 #if     WZinput
-     /* if(r) fputs(_W->R ? " RefGC": " NOrgc",outFILE); */
-	if(r) { if(_W->R) fprintf(outFILE," RefI%d",_W->r);
-		else fputs(" nonRG",outFILE); }
+      /* if(r) fputs(_W->R ? " RefGC": " NOrgc",outFILE); */
+      if(r) { if(_W->R) fprintf(outFILE," RefI%d",_W->r);
+	else fputs(" nonRG",outFILE); }
 #endif 
-     fputs("\n",outFILE);
-}
-     return ;
-  } if((!tc)&&(!rc)){fprintf(outFILE,"non-transversal\n");return;}
+      fputs("\n",outFILE);     }
+    return ;
+  }
+  if((!tc)&&(!rc)){fprintf(outFILE,"non-transversal\n");return;}
   if(_P->n>2){
     if(tc&&rc) for(i=1;i<_P->n-1;i++) if(_VH->h[1][i]!=_BH->h1[i]) 
       { puts("Vafa!=Batyrev"); for(i=1;i<_P->n-1;i++) printf(
 	"V[1,%d]=%d  B[1,%d]=%d\n",i,_VH->h[1][i],i,_BH->h1[i]);exit(0);}
     if(tc)      {	
       fprintf(outFILE,"V:%d",_VH->h[1][1]); 
-      for(i=2;i<_P->n-1;i++) fprintf(outFILE,",%d",_VH->h[1][i]);     }
+      for(i=2;i<_P->n-1;i++) fprintf(outFILE,",%d",_VH->h[1][i]);  
+      if(_P->n > 5){
+	for (j=2; 2*j <= _P->n-1; j++){
+	  fprintf(outFILE,";%d",_VH->h[j][j]);
+	  for(i=j+1;i<_P->n-j;i++) fprintf(outFILE,",%d",_VH->h[j][i]);}}
+    }
     else if(rc)     {	
       fprintf(outFILE,"H:%d",_BH->h1[1]); 
       for(i=2;i<_P->n-1;i++) fprintf(outFILE,",%d",_BH->h1[i]);     }
@@ -236,14 +257,16 @@ void Write_WH(Weight *_W, BaHo *_BH, VaHo *_VH, int rc, int tc,
       if(_P->n==3) chi=4+ho[1];
       if(_P->n==4) chi=2*(ho[1]-ho[2]);
       if(_P->n==5) chi=48+6*(ho[1]-ho[2]+ho[3]);
+      if(_P->n==6) chi=24*(ho[1]-ho[2]+ho[3]-ho[4]);
       fprintf(outFILE," [%d]\n",chi);     }	
     else fprintf(outFILE,"\n");} 
   else fprintf(outFILE,"\n");
 }
+
 void TEST_LatticeBasis(AmbiLatticeBasis *_B)      /* print AmbiLatticeBasis */
 {    int p,a; for(p=0;p<_B->n;p++){
-	for(a=0;a<_B->N;a++) printf(" %3d",(int) _B->x[p][a]); puts("");
-     }	
+	for(a=0;a<_B->N;a++) printf(" %3d",(int) _B->x[p][a]);
+	puts("");     }	
 }
 #ifdef	TEST
 void TEST_WeightMakePoints(AmbiPointList *_P)
@@ -442,7 +465,8 @@ void PrintPoCoLi(PoCoLi *P)
 #endif
 	{ int co=abs(P->c[i]); printf("%s ", i ? 
 	((P->c[i] > 0) ? "+" : "-" ) : "");if(!i&&(P->c[0]<0))printf("- ");
-	if(co!=1) printf("%d ",co); printf("x^%d ",(int)P->e[i]); }}
+	if(co!=1) printf("%d ",co);
+	printf("x^%d ",(int)P->e[i]); }}
      puts(i ? "" : " 0");
 }
 void UnitPoly(PoCoLi *P) { P->n=1; P->e[0]=0; P->c[0]=1; }
@@ -452,7 +476,7 @@ void Add_Mono_2_Poly(int e, Pint c, PoCoLi *P)		   /* use bisection */
      {	int pos=(M+m)/2; if(e > P->e[pos]) m=pos; else 
 	if (e < P->e[pos]) M=pos; else { P->c[pos]+=c; return; }/* e exists */
      }	if(P->A<=P->n){printf("n=A=%d\n",P->A); fflush(0);
-	assert(P->n < P->A);}			/* check #(coeff.) of Poly. */
+       assert(P->n < P->A);}			/* check #(coeff.) of Poly. */
      for(m=P->n++;M<m;m--) {			/* insert new exponent at M */
 	P->c[m]=P->c[m-1]; P->e[m]=P->e[m-1]; } P->e[m]=e;P->c[m]=c;
 #ifdef	TEST_PP
@@ -527,6 +551,7 @@ void Poly_Dif(PoCoLi *A,PoCoLi *B,PoCoLi *D)			/* D = A-B */
 void AllocPoCoLi(PoCoLi *P)			/* allocate e[A] and c[A] */
 {    assert(0<P->A); assert( NULL != ( P->e = (int *) malloc( P->A * 
 	(sizeof(int)+sizeof(Pint) ) ) ));  P->c = (Pint *) & P->e[P->A];
+  // printf("AllocPoCoLi: P->A = %d\n", P->A);
 }
 void Free_PoCoLi(PoCoLi *P) { free(P->e); }	/* free P.e and P.c */
 void PoincarePoly(int N, int *w, int d, PoCoLi *P, PoCoLi *Z,PoCoLi *R)
@@ -568,7 +593,8 @@ int  Hodge_Test(VaHo *V) /* [holo] Poincare duality, Hodge duality, sum rule */
 int  Init_Multiloop(int *N, int *I, int *j, int *J)
 {    long X=1; for(*j=0;*j<*J;(*j)++) {I[*j]=0;assert(N[*j]>0);} assert(0<=*J);
      if((*J)==0) {N[0]=1; I[0]=0;} 		     /*  safe also for J=0   */
-     for(*j=0;*j<*J;(*j)++)X*=N[*j]; *j=0; return X; /* return order=prod(N) */
+     for(*j=0;*j<*J;(*j)++) X*=N[*j];
+     *j=0; return X; /* return order=prod(N) */
 }
 int  Multiloop(int *N,int *I,int *j,int *J)/* need j=I[]=0 => Init_Multiloop */
 {    assert((*j)==0);     if(++(I[0])<N[0]) return 1; 	while(N[*j]<=I[*j])
@@ -577,7 +603,8 @@ int  Multiloop(int *N,int *I,int *j,int *J)/* need j=I[]=0 => Init_Multiloop */
 
 int  Count_b01(Weight *W)
 {    int b=0,c=0,l,M[POLY_Dmax],I[POLY_Dmax],eq[W_Nmax],j,J=W->M,N=W->N,vac=0;
-     for(j=0;j<J;j++) M[j]=W->m[j]; 	for(l=0;l<W->d;l++)      /* Z_d==GSO */
+     for(j=0;j<J;j++) M[j]=W->m[j];
+     for(l=0;l<W->d;l++)      /* Z_d==GSO */
      {	c=Init_Multiloop(M,I,&j,&J); do { 	     /* BEGIN generate group */
 	int i,can=1, sum=0, k;           /* can(didate) for b01-contribution */
         for(i=0;can&&(i<N);i++){Rat th=rR(l*W->w[i],W->d); /* th=0/q -> eq[] */
@@ -614,9 +641,11 @@ void Fast_c9_VaHo(Weight *W,VaHo *V)/* -->> V.D<=3 <<--  via index and trace */
 	assert((b01==0)||(b01==2)); V->h[1][1]=(b01) ? 4 : 20; return;}
      wo[0] = woG = (int *) malloc(WM*3*sizeof(int)); 
      assert(woG!=NULL); wo[1]=woS=&woG[WM]; wo[2]=woA=&woS[WM];
-     for(i=0;i<=N;i++) mask[i]=1<<i; for(i=0;i<=WM;i++) woG[i]=woS[i]=woA[i]=0;
+     for(i=0;i<=N;i++) mask[i]=1<<i;
+     for(i=0;i<=WM;i++) woG[i]=woS[i]=woA[i]=0;
      for(k=0;k<ns;k++) {kgV *= W->m[k]/Fgcd(kgV,W->m[k]); mo*=W->m[k];}
-     for(k=0;k<ns;k++) omega[k]=kgV/W->m[k]; R=kgV/W->d;
+     for(k=0;k<ns;k++) omega[k]=kgV/W->m[k];
+     R=kgV/W->d;
      for(l=0;l<W->d;l++)					 /* Z_d==GSO */
      {  c=Init_Multiloop(W->m,I,&j,&ns); do {        /* BEGIN generate group */
 	nvar=0; for(i=0;i<N;i++) { expo=l*W->w[i]*R; for(k=0;k<ns;k++)expo+=
@@ -654,9 +683,11 @@ int  WIndex_HTrace(Weight *W, int *WI, int *T)/* T=sum(Hij), return over=H00 */
      int *wo[3],*woG,*woA,*woS, WM=1<<W_Nmax,I[POLY_Dmax]; Rat prod;
      wo[0] = woG = (int *) malloc(WM*3*sizeof(int)); 
      assert(woG!=NULL); wo[1]=woS=&woG[WM]; wo[2]=woA=&woS[WM];
-     for(i=0;i<=N;i++) mask[i]=1<<i; for(i=0;i<=WM;i++) woG[i]=woS[i]=woA[i]=0;
+     for(i=0;i<=N;i++) mask[i]=1<<i;
+     for(i=0;i<=WM;i++) woG[i]=woS[i]=woA[i]=0;
      for(k=0;k<ns;k++) {kgV *= W->m[k]/Fgcd(kgV,W->m[k]); mo*=W->m[k];}
-     for(k=0;k<ns;k++) omega[k]=kgV/W->m[k]; R=kgV/W->d;
+     for(k=0;k<ns;k++) omega[k]=kgV/W->m[k];
+     R=kgV/W->d;
      for(l=0;l<W->d;l++)					 /* Z_d==GSO */
      {  c=Init_Multiloop(W->m,I,&j,&ns); do {        /* BEGIN generate group */
 	nvar=0; for(i=0;i<N;i++) { expo=l*W->w[i]*R; for(k=0;k<ns;k++)expo+=
@@ -691,7 +722,8 @@ int  WIndex_HTrace(Weight *W, int *WI, int *T)/* T=sum(Hij), return over=H00 */
  */	
 int Test_BottomUpQuot(PoCoLi *Num,PoCoLi *Den,PoCoLi *Quo,PoCoLi *Rem)
 {   int i=BottomUpQuot(Num,Den,Quo,Rem); if(Rem->n)assert(i==0);
-    if(i)return 1;	printf("Num=");PrintPoCoLi(Num);
+    if(i)return 1;
+    printf("Num="); PrintPoCoLi(Num);
     printf("Den="); PrintPoCoLi(Den); printf("Quo=");PrintPoCoLi(Quo);
     printf("Rem="); PrintPoCoLi(Rem);
 /* printf("N=%d D=%d Q=%d R=%d\n",Num.A,Den.A,Quo.A,Rem.A);exit(0);fflush(0);*/
@@ -707,7 +739,8 @@ typedef	struct {int X, n, *d, **mt;} /* mt[i][j]=mobius(j,i) */	MobiusData;
 
 void MakeMobius(MobiusData *M,int X)   /* d[i] divisors, mt[i][j] 0<=j<=i<=n */
 {    int i,j=0,n=0,*d; 
-     for(i=1;i<X/i;i++) if(X%i==0)n++; M->n=n=2*n+(X==i*i);	/* #(Div(X)) */
+     for(i=1;i<X/i;i++) if(X%i==0)n++;
+     M->n=n=2*n+(X==i*i);	/* #(Div(X)) */
      M->d = d = (int *)malloc(((n*(n+3))/2) * sizeof(int) + n * sizeof(int*));
      assert(d != NULL); M->mt = (int **) &d[(n*(n+3))/2]; M->mt[0]=&(d[n]);
      for(i=1;i<n;i++)M->mt[i]=&M->mt[i-1][i];
@@ -737,14 +770,25 @@ int  Index_Trace_Test(VaHo *V,int WI,int T)
  * to the effectively acting subgroup for each twisted sector		     */
 void LGO_VaHo(Weight *W,VaHo *V)	      
 {    int i,d=W->d,D=0; for(i=0;i<W->N;i++) D+=d-2*W->w[i];assert(!(D%d));D/=d;
-     if((V->sts)||(D>3)) {if(W->M==0) W->m[0]=1;} 
-     else {if(D<=3) {Fast_c9_VaHo(W,V);return;}
-	if(W->M==0){Calc_VaHo(W,V);return;}}
+  /* printf("In LGO_VaHo: W->N: %d W->M: %d D: %d\n", W->N, W->M, D); */
+  /* From palp-2.0 to palp-2.11 the next lines were
+   * if((V->sts)||(D>3)) {if(W->M==0) W->m[0]=1;} 
+   * else {if(D<=3) {Fast_c9_VaHo(W,V);return;}
+   *   if(W->M==0){Calc_VaHo(W,V);return;}}
+   * but that makes no sense since it's equivalent to
+   * if((V->sts)||(D>3)) {if(W->M==0) W->m[0]=1;} 
+   * else {Fast_c9_VaHo(W,V);return;} 
+   * therefore:                                        */
+     if ((V->sts == 0) && (W->M == 0)) {  /* V->sts ... lg-flag set to 2,
+                                            W->M ... # of Z_n symmetries */
+       if (D<=3) {Fast_c9_VaHo(W,V);return;}
+       else {Calc_VaHo(W,V);return;} }
+     if(W->M==0) W->m[0]=1;
      {	Long dQ,QL,q; PoCoLi *S,*SO,*SN;/* dQ=sum(1-2th)=QR-QL; QL=sum(th-w) */
 	int j,k,s, J=W->M, M[POLY_Dmax],I[POLY_Dmax],X=W->m[0],x[POLY_Dmax];
 	int WI,T; Long ph[POLY_Dmax], th[W_Nmax], U=X*d/Fgcd(X,d), rd=U/d, G=1;
 	PoCoLi Den,Num,Quo,Rem; MobiusData MX; MakeMobius(&MX,X);
-	Den.A = (1<<W->N); 	AllocPoCoLi(&Den);
+	Den.A = (1<<W->N);	AllocPoCoLi(&Den);
 	Quo.A = X*d*D+2*W->N; 	AllocPoCoLi(&Quo);
 	Num.A=Rem.A= Quo.A;	AllocPoCoLi(&Num); AllocPoCoLi(&Rem);
 	V->D=D; for(i=0;i<=D;i++) for(j=0;j<=D;j++) V->h[i][j]=0;
@@ -905,13 +949,14 @@ void Calc_VaHo(Weight *W,VaHo *V) {
 #ifndef	COEFF_Nmax
 #define	COEFF_Nmax	(d*D+2*N)		/* 22999000 for W_Nmax == 6 */
 #endif
-     P->A=Z->A=COEFF_Nmax; R->A=w[N-1]+1;	
+     P->A=Z->A=COEFF_Nmax; R->A=w[N-1]+1; //printf("%d %d %d", P->A, Z->A, R->A); 	
      AllocPoCoLi(P); AllocPoCoLi(Z); AllocPoCoLi(R);  
      PoincarePoly(N,w,d,P,Z,R);		
-	assert(D*d==P->e[P->n-1]);
+     assert(D*d==P->e[P->n-1]);
      {  int n=P->n, cM=0; long long sum=0,num=1,den=1; /* check sum = P(0) */
-	for(i=0;i<n;i++) {Pint co=P->c[i]; assert(co>0); 
-	    if(co>cM) cM=co; sum+=co; }
+	for(i=0;i<n;i++) {
+	  Pint co=P->c[i]; assert(co>0); if(co>cM) cM=co;
+	  sum+=co; }
 	for(i=0;i<W->N;i++){	num*=W->d-W->w[i]; den*=W->w[i];
 	   {long long g=LFgcd(num,den); num/=g; den/=g; }} 
 #ifdef	TEST_PP
@@ -987,7 +1032,8 @@ void OLDInit_Trans_Check(int *mask, int **targets, int **mighty)
 int OLDTrans_Check(Weight W){/* returns 1 if non-degenerate potential exists */
    int i, j, k, mon;   			/* j represents the link!!!        */
    static int mask[1+W_Nmax], *targets, *mighty; assert(W.N<=W_Nmax);
-   if(targets==NULL) OLDInit_Trans_Check(mask,&targets,&mighty); targets[0]=0;
+   if(targets==NULL) OLDInit_Trans_Check(mask,&targets,&mighty);
+   targets[0]=0;
    for (i=0;i<W.N;i++) for (j=mask[i];j<mask[i+1];j++){
      targets[j]=0;
      for (k=0;k<=i;k++) targets[j]=targets[j]|targets[j&~mask[k]];
