@@ -1184,7 +1184,8 @@ void Subdivide(PolyPointList *P,int v,Inci64 I[],int p,Inci64 *T,int *t,
     return;
   }	
   else if((P->n!=4)||(p>v+3)) {
-    puts("P* requires triangulation. `mori.x' can triangulate only 4-polytopes");
+    printf("P* requires triangulation. The present routinwes can ");
+    puts("triangulate only 4-polytopes");
     puts("with up to 3 points that are neither vertices nor interior to P* or");
     puts("a facet. Use option `-M' for providing a triangulation as input."); 
     exit(1);}
