@@ -1381,7 +1381,7 @@ void Gen_Ascii_to_Binary(CWS *W, PolyPointList *P,
   VertexNumList V; EqList F;     assert(_NFL!=NULL);
   if(!(*polyo)) {
     puts("You have to specify an output file via -po in -a-mode!\n"); 
-    puts("For more help type `class.x -h'\n");
+    printf("For more help use option '-h'\n");
     exit(0);}
   _NFL->of=0; _NFL->rf=0;       
   _NFL->iname=polyi; _NFL->oname=polyo; _NFL->dbname=dbin; 
