@@ -1759,7 +1759,8 @@ void V_Sublat_Polys(char mr,char *dbin,char *polyi,char *polyo,
      assert(_L!=NULL); 
      if(!(*polyo)) {
 	puts("You have to specify an output file via -po in -sv-mode."); 
-    	puts("For more help type `class.x -h'"); exit(0);}
+    	printf("For more help use option `-h'\n");
+	exit(0);}
      _L->of=0; _L->rf=0; _L->iname=polyi; _L->oname=polyo; _L->dbname=dbin;
      Init_NF_List(_L); _L->SL=0;
      while(Read_H_poly_from_DB_or_inFILE(DB,_P))
