@@ -809,7 +809,7 @@ void Ascii_to_Binary(CWS *W, PolyPointList *P,
   assert(_NFL!=NULL);
   if(!(*polyo)) {
     puts("You have to specify an output file via -po in -a-mode!\n"); 
-    puts("For more help type `class.x -h'\n");
+    printf("For more help type use option `-h'\n");
     exit(0);}
   _NFL->of=0; _NFL->rf=0;	
   _NFL->iname=polyi; _NFL->oname=polyo; _NFL->dbname=dbin; 
@@ -843,7 +843,8 @@ void Do_the_Classification(CWS *W, PolyPointList *P, /* char *fn, */
   time_t W_SAVE_TIME=time(NULL); 
   if(!(*polyo)) { 
     puts("You have to specify an output file via -po!\n"); 
-    puts("For more help type `class.x -h'\n"); exit(0);}
+    printf("For more help use option '-h'\n");
+    exit(0);}
   assert(_NFL!=NULL); _NFL->of=oFlag; _NFL->rf=rFlag; _NFL->kf=kFlag; 
   _NFL->iname=polyi; _NFL->oname=polyo; _NFL->dbname=dbin; 
   Init_NF_List(_NFL);
@@ -1128,7 +1129,7 @@ void Find_Sublat_Polys(char mFlag, char *dbin, char *polyi, char *polyo,
   assert(_NFL!=NULL);
   if(!(*polyo)) {
     puts("You have to specify an output file via -po in -sm-mode."); 
-    puts("For more help type `class.x -h'");
+    printf("For more help use option `-h'\n");
     exit(0);}
   _NFL->of=0; _NFL->rf=0;
   _NFL->iname=polyi; _NFL->oname=polyo; _NFL->dbname=dbin;
