@@ -13,13 +13,11 @@ FILE *inFILE, *outFILE;
 
 typedef struct {  int  u[NFmax];  int nu; } 	CWS_type;
 
-#define OSL (26)  /* opt_string's length */
+#define OSL (24)  /* opt_string's length */
 
-void  PrintCWSUsage(){
+void  PrintCWSUsage(char *c){
   int i;
   char *opt_string[OSL]={
-"This is `cws.x': create weight systems and combined weight systems.",
-"Usage:   cws.x -<options>; the first option must be -w, -c, -i, -d or -h.",
 "Options: -h        print this information",
 "         -f        use as filter; otherwise parameters denote I/O files",
 "         -w# [L H] make IP weight systems for #-dimensional polytopes.",
@@ -45,6 +43,10 @@ void  PrintCWSUsage(){
 "          -2       adjoin a weight of 1/2 to the input weight system.",
 "          -N       make CWS for PPL in N lattice."
 };
+  printf("This is `%s': ", c);
+  puts("create weight systems and combined weight systems.");
+  printf("Usage:   %s -<options>; ", c);
+  puts("the first option must be -w, -c, -i, -d or -h.");
   for (i=0;i<OSL;i++) puts(opt_string[i]);
   exit(0);
 }
@@ -87,7 +89,7 @@ void PrintCWSextUsage(char *c)
 int  main (int narg, char* fn[])
 {    inFILE=stdin; outFILE=stdout;
      if(narg==1) {printf("\nFor help type `%s -h'\n\n",fn[0]);exit(0);}
-     if((fn[1][0]!='-')||(fn[1][1]=='h')) PrintCWSUsage(/*fn[0]*/);
+     if((fn[1][0]!='-')||(fn[1][1]=='h')) PrintCWSUsage(fn[0]);
      else if(fn[1][1]=='w') Init_IP_Weights(narg, fn);
      else if(fn[1][1]=='m') Init_moon_Weights(narg, fn);
      else if(fn[1][1]=='c') Init_IP_CWS(narg, fn);
