@@ -286,7 +286,8 @@ int main(int narg, char *fn[])
 	  if (POLY_Dmax  < (_P->n + codim - 1)){
 	    printf("Please increase POLY_Dmax to at least %d = %d + %d - 1\n",
 		   (_P->n + codim - 1), _P->n, codim);
-	    puts("(nef.x requires POLY_Dmax >= dim N + codim - 1)");
+	    printf("(%s requires POLY_Dmax >= dim N + codim - 1)\n",
+		   fn[0]);
 	    exit(0);	  }
 	  Make_E_Poly(outFILE, &CW, _P, _V, _E, &codim, &F, &D[0]);	}
 	else{
